@@ -30,7 +30,7 @@ class Decompressor():
                     
             await asyncio.gather(*tasks)
 
-        cleanup(local_temp_dir)
+        self.cleanup(local_temp_dir)
 
     async def process_blob_file(self, container_name, blob_client, dest_dir, local_file):
         print(f"start processing file: {local_file}")
@@ -92,5 +92,5 @@ class Decompressor():
             if exc.errno != errno.EEXIST:
                 raise      
 
-    def cleanup(local_temp_dir):
+    def cleanup(self, local_temp_dir):
         shutil.rmtree(local_temp_dir)
\ No newline at end of file
